use vulkano::device::{DeviceExtensions, DeviceFeatures};
use vulkano_util::context::{VulkanoConfig, VulkanoContext};
use winit::event_loop::{ControlFlow, EventLoop};

mod render;
fn main() {
    env_logger::init();

    let device_extensions = DeviceExtensions {
        khr_swapchain: true,
        ..Default::default()
    };

    let device_features = DeviceFeatures {
        dynamic_rendering: true,
        ..Default::default()
    };

    let vulkano_config = VulkanoConfig {
        print_device_name: true,
        device_extensions,
        device_features,
        ..Default::default()
    };

    let vulkano_context = VulkanoContext::new(vulkano_config);

    let event_loop = EventLoop::new().unwrap();
    event_loop.set_control_flow(ControlFlow::Poll);

    let mut app = render::app::App::from(vulkano_context);

    match event_loop.run_app(&mut app) {
        Ok(_) => {}
        Err(e) => {
            log::error!("Error running old app: {e}");
        }
    }
}
