use std::sync::Arc;

use vulkano::{
    command_buffer::allocator::StandardCommandBufferAllocator,
    descriptor_set::allocator::StandardDescriptorSetAllocator,
};
use vulkano_util::context::VulkanoContext;

pub struct VulkanContext {
    vulkano_context: VulkanoContext,
    command_buffer_allocator: Arc<StandardCommandBufferAllocator>,
    descriptor_set_allocator: Arc<StandardDescriptorSetAllocator>,
}

impl VulkanContext {
    pub fn new(vulkano_context: VulkanoContext) -> Self {
        let command_buffer_allocator = Arc::new(StandardCommandBufferAllocator::new(
            vulkano_context.device().clone(),
            Default::default(),
        ));

        let descriptor_set_allocator = Arc::new(StandardDescriptorSetAllocator::new(
            vulkano_context.device().clone(),
            Default::default(),
        ));

        Self {
            vulkano_context,
            command_buffer_allocator,
            descriptor_set_allocator,
        }
    }

    pub fn vulkano_context(&self) -> &VulkanoContext {
        &self.vulkano_context
    }

    pub fn command_buffer_allocator(&self) -> &Arc<StandardCommandBufferAllocator> {
        &self.command_buffer_allocator
    }

    pub fn descriptor_set_allocator(&self) -> &Arc<StandardDescriptorSetAllocator> {
        &self.descriptor_set_allocator
    }
}
